==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/cs-CZ/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Vlastní pole',
    'manage'                    => 'Spravovat',
    'field'		                => 'Pole',
    'about_fieldsets_title'		=> 'O sadách polí',
    'about_fieldsets_text'		=> 'Sady polí Vám umožňují vytvořit si vlastní hodnoty, které chcete evidovat u modelů majetku.',
    'custom_format'             => 'Vlastní formát regexu...',
    'encrypt_field'      	        => 'Zašifrovat hodnotu tohoto pole v databázi',
    'encrypt_field_help'      => 'UPOZORNĚNÍ: Šifrování pole je udělá nevyhledatelné.',
    'encrypted'      	        => 'Šifrováno',
    'fieldset'      	        => 'Sada',
    'qty_fields'      	      => 'Počet',
    'fieldsets'      	        => 'Sady',
    'fieldset_name'           => 'Název sady',
    'field_name'              => 'Název pole',
    'field_values'            => 'Hodnota',
    'field_values_help'       => 'Přidat možnosti výběru, jedna možnost na řádek. Prázdné řádky jiné než první řádek budou ignorovány.',
    'field_element'           => 'Typ pole',
    'field_element_short'     => 'Typ',
    'field_format'            => 'Formát',
    'field_custom_format'     => 'Vlastní formát',
    'field_custom_format_help'     => 'Toto pole umožňuje použít pro validaci regulární výrazy. Mělo by začínat slovem "regex:" - například pro ověření, že zadaná hodnota pole obsahuje platný IMEI (15 číslic), použijte <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Povinné',
    'req'   		              => 'Pov.',
    'used_by_models'   		    => 'Užito u modelů',
    'order'   		            => 'Pořadí',
    'create_fieldset'         => 'Nová sada',
    'update_fieldset'         => 'Upravit sadu polí',
    'fieldset_does_not_exist'   => 'Sada polí neexistuje',
    'fieldset_updated'         => 'Sada polí upravena',
    'create_fieldset_title' => 'Vytvořit nový fieldset',
    'create_field'            => 'Nové vlastní pole',
    'create_field_title' => 'Vytvořít vlastní fieldset',
    'value_encrypted'      	        => 'Hodnota tohoto pole je zašifrována v databázi. Pouze administrátoři budou moci zobrazit dešifrovanou hodnotu',
    'show_in_email'     => 'Zahrnout hodnotu této kolonky do e-mailu o vyskladnění pro uživatele? Šifrované kolonky nemohou být součástí e-mailů',
    'show_in_email_short'     => 'Zahrnout do e-mailů.',
    'help_text' => 'Text nápovědy',
    'help_text_description' => 'Toto je volitelný text, který se zobrazí pod formulářovými prvky při úpravách aktiva pro poskytnutí kontextu v poli.',
    'about_custom_fields_title' => 'O vlastních polích',
    'about_custom_fields_text' => 'Vlastní pole umožňují přidat libovolné atributy k aktivům.',
    'add_field_to_fieldset' => 'Přidat pole do fieldsetu',
    'make_optional' => 'Vyžadováno - klikněte pro nastavení na volitelné',
    'make_required' => 'Volitelné - klikněte pro nastavení na vyžadované',
    'reorder' => 'Změnit pořadí',
    'db_field' => 'Databázové pole',
    'db_convert_warning' => 'VAROVÁNÍ. Toto pole je v tabulce vlastních polí jako <code>:db_column</code>, ale mělo by být <code>:expected</code>.',
    'is_unique' => 'Tato hodnota musí být jedinečná pro všechny aktiva',
    'unique' => 'Unikátní',
    'display_in_user_view' => 'Povolit uživateli vyhledat tyto hodnoty na stránce Zobrazit přiřazené položky',
    'display_in_user_view_table' => 'Viditelné pro uživatele',
    'auto_add_to_fieldsets' => 'Automaticky přidat do každé nové sady polí',
    'add_to_preexisting_fieldsets' => 'Přidat do všech stávajících sad polí',
    'show_in_listview' => 'Zobrazovat v seznamech. Autorizovaní uživatelé si hodnotu i nadále budou moci skrýt skrze výběr sloupců',
    'show_in_listview_short' => 'Zobrazovat v seznamech',
    'show_in_requestable_list_short' => 'Zobrazit v seznamu požadovaných položek',
    'show_in_requestable_list' => 'Zobrazit hodnotu v seznamu požadovaných aktiv. Šifrovaná pole nebudou zobrazena',
    'encrypted_options' => 'Toto pole je šifrované, takže některé možnosti zobrazení nebudou k dispozici.',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/cs-CZ/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Vlastní pole',
    'manage'                    => 'Spravovat',
    'field'		                => 'Pole',
    'about_fieldsets_title'		=> 'O sadách polí',
    'about_fieldsets_text'		=> 'Sady polí Vám umožňují vytvořit si vlastní hodnoty, které chcete evidovat u modelů majetku.',
    'custom_format'             => 'Vlastní formát regexu...',
    'encrypt_field'      	        => 'Zašifrovat hodnotu tohoto pole v databázi',
    'encrypt_field_help'      => 'UPOZORNĚNÍ: Šifrování pole je udělá nevyhledatelné.',
    'encrypted'      	        => 'Šifrováno',
    'fieldset'      	        => 'Sada',
    'qty_fields'      	      => 'Počet',
    'fieldsets'      	        => 'Sady',
    'fieldset_name'           => 'Název sady',
    'field_name'              => 'Název pole',
    'field_values'            => 'Hodnota',
    'field_values_help'       => 'Přidat možnosti výběru, jedna možnost na řádek. Prázdné řádky jiné než první řádek budou ignorovány.',
    'field_element'           => 'Typ pole',
    'field_element_short'     => 'Typ',
    'field_format'            => 'Formát',
    'field_custom_format'     => 'Vlastní formát',
    'field_custom_format_help'     => 'Toto pole umožňuje použít pro validaci regulární výrazy. Mělo by začínat slovem "regex:" - například pro ověření, že zadaná hodnota pole obsahuje platný IMEI (15 číslic), použijte <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Povinné',
    'req'   		              => 'Pov.',
    'used_by_models'   		    => 'Užito u modelů',
    'order'   		            => 'Pořadí',
    'create_fieldset'         => 'Nová sada',
    'update_fieldset'         => 'Upravit sadu polí',
    'fieldset_does_not_exist'   => 'Sada polí neexistuje',
    'fieldset_updated'         => 'Sada polí upravena',
    'create_fieldset_title' => 'Vytvořit nový fieldset',
    'create_field'            => 'Nové vlastní pole',
    'create_field_title' => 'Vytvořít vlastní fieldset',
    'value_encrypted'      	        => 'Hodnota tohoto pole je zašifrována v databázi. Pouze administrátoři budou moci zobrazit dešifrovanou hodnotu',
    'show_in_email'     => 'Zahrnout hodnotu této kolonky do e-mailu o vyskladnění pro uživatele? Šifrované kolonky nemohou být součástí e-mailů',
    'show_in_email_short' => 'Zahrnout do e-mailů',
    'help_text' => 'Text nápovědy',
    'help_text_description' => 'Toto je volitelný text, který se zobrazí pod formulářovými prvky při úpravách aktiva pro poskytnutí kontextu v poli.',
    'about_custom_fields_title' => 'O vlastních polích',
    'about_custom_fields_text' => 'Vlastní pole umožňují přidat libovolné atributy k aktivům.',
    'add_field_to_fieldset' => 'Přidat pole do fieldsetu',
    'make_optional' => 'Vyžadováno - klikněte pro nastavení na volitelné',
    'make_required' => 'Volitelné - klikněte pro nastavení na vyžadované',
    'reorder' => 'Změnit pořadí',
    'db_field' => 'Databázové pole',
    'db_convert_warning' => 'VAROVÁNÍ. Toto pole je v tabulce vlastních polí jako <code>:db_column</code>, ale mělo by být <code>:expected</code>.',
    'is_unique' => 'Tato hodnota musí být jedinečná pro všechny aktiva',
    'unique' => 'Unikátní',
    'display_in_user_view' => 'Povolit uživateli vyhledat tyto hodnoty na stránce Zobrazit přiřazené položky',
    'display_in_user_view_table' => 'Viditelné pro uživatele',
    'auto_add_to_fieldsets' => 'Automaticky přidat do každé nové sady polí',
    'add_to_preexisting_fieldsets' => 'Přidat do všech stávajících sad polí',
    'show_in_listview' => 'Zobrazovat v seznamech. Autorizovaní uživatelé si hodnotu i nadále budou moci skrýt skrze výběr sloupců',
    'show_in_listview_short' => 'Zobrazovat v seznamech',
    'show_in_requestable_list_short' => 'Zobrazit v seznamu požadovaných položek',
    'show_in_requestable_list' => 'Zobrazit hodnotu v seznamu požadovaných aktiv. Šifrovaná pole nebudou zobrazena',
    'encrypted_options' => 'Toto pole je šifrované, takže některé možnosti zobrazení nebudou k dispozici.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];
